Welcome to teststack's documentation!
=====================================

Teststack is meant to be a replacement for ``docker-compose`` and be more
focused around running test suites instead of focused on setting up
environments.

The ideal workflow is someone should be able to clone a repository and then just
execute ``teststack run`` and the test suite is setup and run without them
having to know anything else about the application.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   usage
   config
   commands/index.rst
   containers/index.rst

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
